"use client";

import { useEffect, useRef, useState } from "react";
import { useRouter } from "next/navigation";
import { useAuth } from "@/lib/hooks/useAuth";
import { useTeachers } from "@/lib/hooks/useTeachers";
import DashboardLayout from "@/components/layout/DashboardLayout";
import { Button } from "@/components/ui/button";
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";
import { ArrowLeft, BookOpen, CalendarCheck, Camera, Home, Mail, Phone, Table, User, X } from "lucide-react";
import { Teacher } from "@/lib/types";
import { useClasses } from "@/lib/hooks/useClasses";
import { Class } from "@/lib/types";
import { TableHeader, TableRow, TableHead, TableBody, TableCell } from "@/components/ui/table";
import { toast } from "sonner";

export default function TeacherDetailsPage({ params }: { params: { id: string } }) {
  const router = useRouter();
  const { user } = useAuth();
  const { teachers, updateTeacher } = useTeachers();
  const [teacher, setTeacher] = useState<Teacher | null>(null);
  const { getClassesByTeacher } = useClasses();
  const [teacherClasses, setTeacherClasses] = useState<Class[]>([]);
  const [loadingClasses, setLoadingClasses] = useState(false);
  const [isUploading, setIsUploading] = useState(false);
  const fileInputRef = useRef<HTMLInputElement>(null);
  const [isImageModalOpen, setIsImageModalOpen] = useState(false);

  
useEffect(() => {
  let isMounted = true;

  const fetchData = async () => {
    if (!params.id || teachers.length === 0) {
      setLoadingClasses(false);
      return;
    }

    const foundTeacher = teachers.find(t => t.id === params.id);
    if (!foundTeacher) {
      setTeacher(null);
      setLoadingClasses(false);
      return;
    }

    setTeacher(foundTeacher);
    setLoadingClasses(true);

    try {
      const classes = await getClassesByTeacher(foundTeacher.id);

      if (isMounted) {
        setTeacherClasses(classes);
      }
    } catch (error) {
      console.error('Error fetching classes:', error);
      if (isMounted) {
        setTeacherClasses([]);
        toast.error('Failed to load classes');
      }
    } finally {
      if (isMounted) {
        setLoadingClasses(false);
      }
    }
  };

  fetchData();

  return () => {
    isMounted = false;
  };
}, [params.id, teachers]);

  const handlePhotoUpload = async (e: React.ChangeEvent<HTMLInputElement>) => {
    const file = e.target.files?.[0];
    if (!file || !teacher) return;

    try {
      setIsUploading(true);
      
      // Create FormData and append file
      const formData = new FormData();
      formData.append('file', file);
      
      // Upload file to server
      const response = await fetch('/api/upload', {
        method: 'POST',
        body: formData,
      });

      if (!response.ok) throw new Error('Failed to upload image');

      const { url } = await response.json();
      
      // Update teacher profile with new photo URL
      await updateTeacher(teacher.id, { profilePicture: url });
      setTeacher({ ...teacher, profilePicture: url });
        toast.success("Profile picture updated successfully", {
          style: {
            background: '#4BB543', // Green color for success
            color: '#ffffff',
            border: '1px solid #3FAF3A',
          },
        });
    } catch (error) {
      console.error("Error uploading photo:", error);
      toast.error("Failed to upload profile picture", {
        style: {
          background: '#FF3333', // Red color for error
          color: '#ffffff',
          border: '1px solid #E60000',
        },
      });
    } finally {
      setIsUploading(false);
    }
  };

  if (!teacher) {
    return (
      <DashboardLayout>
        <div className="flex items-center justify-center h-[calc(100vh-4rem)]">
          <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-primary"></div>
        </div>
      </DashboardLayout>
    );
  }

  return (
    <DashboardLayout>
      <div className="space-y-6">
        <div className="flex items-center gap-4">
          <Button
            variant="ghost"
            size="sm"
            onClick={() => router.back()}
          >
            <ArrowLeft className="h-4 w-4 mr-2" />
            Back
          </Button>
          <div>
            <h1 className="text-3xl font-bold tracking-tight">Teacher Profile</h1>
            <p className="text-muted-foreground">
              View detailed information about {teacher.firstName} {teacher.lastName}
            </p>
          </div>
        </div>

        <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
          <Card>
            <CardHeader>
              <CardTitle>Personal Information</CardTitle>
            </CardHeader>
            <CardContent className="space-y-4">
              <div className="flex items-center gap-4">
          <div className="relative">
                  {teacher.profilePicture ? (
                    <>
                      <img
                        src={teacher.profilePicture}
                        alt={`${teacher.firstName} ${teacher.lastName}`}
                        className="h-24 w-24 rounded-full object-cover border-2 border-border cursor-pointer hover:opacity-80 transition-opacity"
                        onClick={() => setIsImageModalOpen(true)}
                      />
                      
                      {/* Modal for full-size image */}
                      {isImageModalOpen && (
                        <div className="fixed inset-0 bg-black/80 z-50 flex items-center justify-center p-4">
                          <div className="relative bg-background rounded-lg max-w-4xl max-h-[90vh] overflow-auto">
                            <img
                              src={teacher.profilePicture}
                              alt={`${teacher.firstName} ${teacher.lastName}`}
                              className="w-full h-auto max-h-[80vh] object-contain"
                            />
                            <button
                              onClick={() => setIsImageModalOpen(false)}
                              className="absolute top-4 right-4 p-2 rounded-full bg-foreground/10 hover:bg-foreground/20 transition-colors"
                            >
                              <X className="h-6 w-6 text-white" />
                            </button>
                          </div>
                        </div>
                      )}
                    </>
                  ) : (
                    <div className="h-24 w-24 rounded-full bg-primary/10 flex items-center justify-center border-2 border-border">
                      <User className="h-12 w-12 text-primary" />
                    </div>
                  )}
          
                  {(user?.role === "admin" || user?.role === "teacher") && (
                    <Button
                      size="sm"
                      variant="secondary"
                      className="absolute -bottom-2 -right-2 h-8 w-8 rounded-full p-0"
                      onClick={() => fileInputRef.current?.click()}
                      disabled={isUploading}
                    >
                      <Camera className="h-4 w-4" />
                    </Button>
                  )}
          
                  <input
                    type="file"
                    ref={fileInputRef}
                    className="hidden"
                    accept="image/*"
                    onChange={handlePhotoUpload}
                  />
                    </div>
                <div>
                  <h2 className="text-2xl font-bold">
                    {teacher.firstName} {teacher.lastName}
                  </h2>
                  {isUploading && (
                    <p className="text-sm text-muted-foreground">Uploading...</p>
                  )}
                </div>
              </div>

              <div className="space-y-2">
                <div className="flex items-center gap-2">
                  <Mail className="h-4 w-4 text-muted-foreground" />
                  <span>{teacher.email}</span>
                </div>
                <div className="flex items-center gap-2">
                  <Phone className="h-4 w-4 text-muted-foreground" />
                  <span>{teacher.phone}</span>
                </div>
                <div className="flex items-center gap-2">
                  <CalendarCheck className="h-4 w-4 text-muted-foreground" />
                  <span>{new Date(teacher.dateOfBirth).toLocaleDateString('en-GB', {
                      day: '2-digit',
                      month: 'long',
                      year: 'numeric'
                    })}</span>
                </div>
                <div className="flex items-center gap-2">
                  <Home className="h-4 w-4 text-muted-foreground" />
                  <p>{teacher.address}</p>
                </div>
              </div>
            </CardContent>
          </Card>

          <Card>
            <CardHeader>
              <CardTitle>Professional Information</CardTitle>
            </CardHeader>
            <CardContent className="space-y-4">
              <div className="grid grid-cols-2 gap-4">
                <div>
                  <p className="text-sm text-muted-foreground">Joining Date</p>
                  <p className="font-medium">
                    {new Date(teacher.joiningDate).toLocaleDateString('en-GB', {
                      day: '2-digit',
                      month: 'long',
                      year: 'numeric'
                    })}
                  </p>
                </div>
                <div>
                  <p className="text-sm text-muted-foreground">Status</p>
                  <span
                    className={`inline-flex items-center rounded-full px-2.5 py-0.5 text-xs font-medium ${
                      teacher.status === "active"
                        ? "bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-300"
                        : teacher.status === "inactive"
                        ? "bg-yellow-100 text-yellow-800 dark:bg-yellow-900 dark:text-yellow-300"
                        : "bg-red-100 text-red-800 dark:bg-red-900 dark:text-red-300"
                    }`}
                  >
                    {teacher.status}
                  </span>
                </div>
                <div className="flex items-center gap-2">
                  <BookOpen className="h-4 w-4 text-muted-foreground" />
                  <span>Qualification: {teacher.qualification}</span>
                </div>
              </div>
            </CardContent>
          </Card>
        </div>

       <Card>
  <CardHeader>
    <CardTitle>Assigned Classes</CardTitle>
  </CardHeader>
  <CardContent>
    {loadingClasses ? (
      <div className="flex items-center justify-center py-8">
        <div className="animate-spin rounded-full h-8 w-8 border-t-2 border-b-2 border-primary"></div>
        <span className="ml-2">Loading classes...</span>
      </div>
    ) : teacherClasses.length > 0 ? (
      <div className="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 gap-4">
        {teacherClasses.map((cls) => (
          <div key={cls.id} className="border rounded-lg p-4 hover:bg-accent transition-colors">
            <div className="flex items-center gap-2">
              {/* <BookOpen className="h-5 w-5 text-primary" /> */}
              <h3 className="font-medium text-lg">{cls.name}</h3>
            </div>
            <p className="text-muted-foreground mt-1">{cls.level}</p>
          </div>
        ))}
      </div>
    ) : (
      <div className="flex flex-col items-center justify-center py-8 space-y-2">
        <BookOpen className="h-6 w-6 text-muted-foreground" />
        <p className="text-muted-foreground">No classes assigned yet</p>
      </div>
    )}
  </CardContent>
</Card>
      </div>
    </DashboardLayout>
  );
}


